<!--
This file is part of CoVeriTeam,
a tool for on-demand composition of cooperative verification systems:
https://gitlab.com/sosy-lab/software/coveriteam

SPDX-FileCopyrightText: 2020 Dirk Beyer <https://www.sosy-lab.org>

SPDX-License-Identifier: Apache-2.0
-->

## CoVeriTeam 0.2
* New formal for YAML file
* setting up PyPi release

## CoVeriTeam 0.1
Initial version of CoVeriTeam as available on Zenodo: https://doi.org/10.5281/zenodo.3818283
